@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Convert chords to Roman numeral notation
 
-our $VERSION = '0.0300';
+our $VERSION = '0.0400';
 
 use Moo;
 use strictures 2;
@@ -34,10 +34,29 @@ has chords => (
 sub parse {
     my ( $self, $chord ) = @_;
 
-    # XXX Assume minor if not major!
-    my @roman = $self->scale_name eq 'major'
-        ? qw( I ii iii IV V vi vii )
-        : qw( i ii III iv v VI VII );
+    # Literal diatonic modes when chords attribute is zero
+    my @roman;
+    if ( $self->scale_name eq 'major' || $self->scale_name eq 'ionian' ) {
+        @roman = qw( I ii iii IV V vi vii );
+    }
+    elsif ( $self->scale_name eq 'dorian' ) {
+        @roman = qw( i ii III IV v vi VII );
+    }
+    elsif ( $self->scale_name eq 'phrygian' ) {
+        @roman = qw( i II III iv v VI vii );
+    }
+    elsif ( $self->scale_name eq 'lydian' ) {
+        @roman = qw( I II iii iv V vi vii );
+    }
+    elsif ( $self->scale_name eq 'mixolydian' ) {
+        @roman = qw( I ii iii IV v vi VII );
+    }
+    elsif ( $self->scale_name eq 'minor' || $self->scale_name eq 'aeolian' ) {
+        @roman = qw( i ii III iv v VI VII );
+    }
+    elsif ( $self->scale_name eq 'locrian' ) {
+        @roman = qw( i II iii iv V VI vii );
+    }
 
     # Get the scale notes
     my @notes = get_scale_notes( $self->scale_note, $self->scale_name );
@@ -105,7 +124,7 @@ Music::ToRoman - Convert chords to Roman numeral notation
 
 =head1 VERSION
 
-version 0.0300
+version 0.0400
 
 =head1 SYNOPSIS
 
@@ -125,7 +144,7 @@ version 0.0300
   # Also:
   $mtr = Music::ToRoman->new(
     scale_note => 'A',
-    scale_name => 'minor',
+    scale_name => 'dorian',
     chords     => 0,
   );
   $roman = $mtr->parse('A'); # i
@@ -134,19 +153,28 @@ version 0.0300
 
 =head1 DESCRIPTION
 
-C<Music::ToRoman> converts chords to Roman numeral notation.
+C<Music::ToRoman> converts chords to Roman numeral notation.  Also individual
+"chordless" notes may be converted given a diatonic mode B<scale_name>.
 
 =head1 ATTRIBUTES
 
 =head2 scale_note
 
-Note on which the scale is based.  This can be one of C, D, E, F, G, A or B.
+Note on which the scale is based.  This can be one of C, Cb, C#, D, Db, D# ...
 
 Default: C
 
 =head2 scale_name
 
-Name of the scale.  See L<Music::Scales/SCALES> for the possible names.
+Name of the scale.  The diatonic mode names supported are:
+
+  ionian / major
+  dorian
+  phrygian
+  lydian
+  mixolydian
+  aeolian / minor
+  locrian
 
 Default: major
 
@@ -156,6 +184,9 @@ Are we given chords with major ("M") and minor ("m") designations?
 
 Default: 1
 
+If this is set to 0, then only diatonic mode B<scale_name> output is rendered
+(other scales are ignored).
+
 =head1 METHODS
 
 =head2 new()
